==> gnome-games-1.4.0.1.tar.gz: gnome-games-1.4.0.1/xbill/Strings.h <==
#ifndef STRINGS_H
#define STRINGS_H

#define storystr \
"             The Story:\n\
\n\
Yet again, the fate of the world rests\n\
in your hands!  An evil computer hacker,\n\
known only by his handle 'Bill', has\n\
created the ultimate computer virus.  A\n\
virus so powerful that it has the power\n\
to transmute an ordinary computer into\n\
a toaster oven.  (oooh!) 'Bill' has\n\
cloned himself into a billion-jillion\n\
micro-Bills.  Their sole purpose is to\n\
deliver the nefarious virus, which has\n\
been cleverly diguised as a popular\n\
operating system.\n\
\n\
As System Administrator/Exterminator,\n\
your job is to keep Bill from succeeding\n\
at his task."

#define rulesstr \
"             The Rules:\n\
\n\
xBill has been painstakingly designed and\n\
researched in order to make it as easy to use\n\
for the whole family as it is for little Sally.\n\
Years - nay - days of beta testing and \n\
consulting with the cheapest of human interface\n\
designers have resulted in a game that is easy\n\
to use, yet nothing at all like a Macintosh.\n\
\n\
I.   Whack the Bills (click)\n\
II.  Restart the computer (click)\n\
III. Pick up stolen OSes & return(drag)\n\
     them to their respective computers\n\
IV.  Drag the bucket to extinguish sparks\n\
V.   Scoring is based on total uptime,\n\
     with bonuses for killing Bills.\n\
\n\
As for the rest, you can probably figure\n\
it out.  We did, so it can't be too hard."

#define endgamestr \
"Module xBill has caused a segmentation fault\n\
at memory address 097E:F1A0.  Core dumped.\n\
\n\
    We apologize for the inconvenience."

#define warpstr "Warp to level?"
#define quitstr "Quit Game?"
#define newgamestr "New Game?"
#define pausestr "Game paused.  Press Continue to continue."
#define enternamestr "You earned a high score.\nEnter your name:"

#endif

==> gnome-games-1.90.1.tar.gz: gnome-games-1.90.1/xbill/Strings.h <==
#ifndef STRINGS_H
#define STRINGS_H

#define storystr \
_("             The Story:\n\
\n\
Yet again, the fate of the world rests\n\
in your hands!  An evil computer hacker,\n\
known only by his handle 'Bill', has\n\
created the ultimate computer virus.  A\n\
virus so powerful that it has the power\n\
to transmute an ordinary computer into\n\
a toaster oven.  (oooh!) 'Bill' has\n\
cloned himself into a billion-jillion\n\
micro-Bills.  Their sole purpose is to\n\
deliver the nefarious virus, which has\n\
been cleverly diguised as a popular\n\
operating system.\n\
\n\
As System Administrator/Exterminator,\n\
your job is to keep Bill from succeeding\n\
at his task.")

#define rulesstr \
_("             The Rules:\n\
\n\
xBill has been painstakingly designed and\n\
researched in order to make it as easy to use\n\
for the whole family as it is for little Sally.\n\
Years - nay - days of beta testing and \n\
consulting with the cheapest of human interface\n\
designers have resulted in a game that is easy\n\
to use, yet nothing at all like a Macintosh.\n\
\n\
I.   Whack the Bills (click)\n\
II.  Restart the computer (click)\n\
III. Pick up stolen OSes & return(drag)\n\
     them to their respective computers\n\
IV.  Drag the bucket to extinguish sparks\n\
V.   Scoring is based on total uptime,\n\
     with bonuses for killing Bills.\n\
\n\
As for the rest, you can probably figure\n\
it out.  We did, so it can't be too hard.")

#define endgamestr \
_("Module xBill has caused a segmentation fault\n\
at memory address 097E:F1A0.  Core dumped.\n\
\n\
    We apologize for the inconvenience.")

#define warpstr _("Warp to level?")
#define quitstr _("Quit Game?")
#define newgamestr _("New Game?")
#define pausestr _("Game paused.  Press Continue to continue.")
#define enternamestr _("You earned a high score.\nEnter your name:")

#endif
